@@ -87,7 +87,7 @@ class Attention(Module):
         dim_head,
         heads,
         key,
-        mask_value = 1e-10
+        mask_value = -1e10
     ):
         inner_dim = dim_head * heads
         self.norm = LayerNorm(dim)
@@ -132,7 +132,6 @@ class Attention(Module):
 
         # attention
 
-        sim -= np.max(sim, axis = -1, keepdims = True)
         attn = nn.softmax(sim, axis = -1)
 
         # aggregate values
